==> node-red-contrib-bittrex-0.0.1.tgz: package/bittrex.js <==
module.exports = function(RED) {	
	var bittrexClient = require('node.bittrex.api');	
	
    function BittrexNode(n) {
        RED.nodes.createNode(this,n);
		//console.log(n);
		this.token = RED.nodes.getNode(n.token);
        var credentials = RED.nodes.getCredentials(n.token);
		//console.log(this.tokenconfig);
		//console.log(credentials);
        //this.token = this.tokenconfig;
        var node = this;
		var bittrex = require('node.bittrex.api');	
		
		bittrex.options({
		  'verbose' : true,
		});

		console.log('Connecting ....');
		bittrex.websockets.subscribe(['BTC-ETH','BTC-SC','BTC-ZEN'], function(data, client) {
		  if (data.M === 'updateExchangeState') {
			data.A.forEach(function(data_for) {
			  console.log('Market Update for '+ data_for.MarketName, data_for);
			});
		  }
		});
		
		//var websocketClient;
		//bittrexClient.websockets.client(function(client) {
		//  websocketClient = client;
		//});

		
		//bittrexClient.websockets.subscribe(['BTC-MUE','BTC-UBQ'], function(data, client) {
		//  console.log( data );
		//  if (data.M === 'updateExchangeState') {
		//	data.A.forEach(function(data_for) {
		//	  console.log('Market Update for '+ data_for.MarketName, data_for);
		//	});
		//  }
		//});
				console.log( "websockets" );
			
        node.on('input', function(msg) {
			msg.cred = RED.nodes.getCredentials(n.token).apikey;
			node.send(msg);
        });

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("bittrex in",BittrexNode);
	
	function BittrexTickerNode(n) {
        RED.nodes.createNode(this,n);
		this.token = RED.nodes.getNode(n.token);
		this.market = n.market;
        var credentials = RED.nodes.getCredentials(n.token);
        var node = this;		
		
		bittrexClient.options({
		  'apikey' : credentials.apikey,
		  'apisecret' : credentials.apisecret, 
		});
			
        node.on('input', function(msg) {
			bittrexClient.getticker( { market : this.market }, function( data, err ) {
				if (err) {
					setErrorState(err);
				}
				node.send({payload: data.result});
			});			
        });
		
		function setErrorState(err) {
			node.status({fill:"red",shape:"ring",text:err})
        }

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("ticker",BittrexTickerNode);
	
	function BittrexBalanceNode(n) {
        RED.nodes.createNode(this,n);
		this.token = RED.nodes.getNode(n.token);
		this.currency = n.currency;
        var credentials = RED.nodes.getCredentials(n.token);
        var node = this;		
		
		bittrexClient.options({
		  'apikey' : credentials.apikey,
		  'apisecret' : credentials.apisecret, 
		});
			
        node.on('input', function(msg) {
			if (this.currency){
				bittrexClient.getbalance({ currency : this.currency }, function( data, err ) {
				  if (err) {
					setErrorState(err);
				  }
				  node.send({payload: data.result.Balance});
				  
				});	
			} else {
				bittrexClient.getbalances( function( data, err ) {
				  if (err) {
					return console.error(err);
				  }
				  
				  var result = {};
				  for (i in data.result) {
					result[data.result[i].Currency] = data.result[i].Balance
				  }
				  node.send({payload: result});
				});
			}			
        });
		
		function setErrorState(err) {
			node.status({fill:"red",shape:"ring",text:err})
        }

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("balance",BittrexBalanceNode);

	function BittrexTokenNode(n) {
        RED.nodes.createNode(this,n);
        this.name = n.name;
    }
    RED.nodes.registerType("bittrex-token",BittrexTokenNode,{
        credentials: {
            apikey: {type: "password"},
			apisecret: {type: "password"},
        }
    });
}

==> node-red-contrib-bittrex-0.0.2.tgz: package/bittrex.js <==
module.exports = function(RED) {	
	var bittrexClient = require('node.bittrex.api');	
	
    function BittrexNode(n) {
        RED.nodes.createNode(this,n);
		//console.log(n);
		this.token = RED.nodes.getNode(n.token);
        var credentials = RED.nodes.getCredentials(n.token);
		//console.log(this.tokenconfig);
		//console.log(credentials);
        //this.token = this.tokenconfig;
        var node = this;
		var bittrex = require('node.bittrex.api');	
		
		bittrex.options({
		  'verbose' : true,
		});

		console.log('Connecting ....');
		bittrex.websockets.subscribe(['BTC-ETH','BTC-SC','BTC-ZEN'], function(data, client) {
		  if (data.M === 'updateExchangeState') {
			data.A.forEach(function(data_for) {
			  console.log('Market Update for '+ data_for.MarketName, data_for);
			});
		  }
		});
		
		//var websocketClient;
		//bittrexClient.websockets.client(function(client) {
		//  websocketClient = client;
		//});

		
		//bittrexClient.websockets.subscribe(['BTC-MUE','BTC-UBQ'], function(data, client) {
		//  console.log( data );
		//  if (data.M === 'updateExchangeState') {
		//	data.A.forEach(function(data_for) {
		//	  console.log('Market Update for '+ data_for.MarketName, data_for);
		//	});
		//  }
		//});
				console.log( "websockets" );
			
        node.on('input', function(msg) {
			msg.cred = RED.nodes.getCredentials(n.token).apikey;
			node.send(msg);
        });

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("bittrex in",BittrexNode);
	
	function BittrexTickerNode(n) {
        RED.nodes.createNode(this,n);
		this.token = RED.nodes.getNode(n.token);
		this.market = n.market;
        var credentials = RED.nodes.getCredentials(n.token);
        var node = this;		
		
		bittrexClient.options({
		  'apikey' : credentials.apikey,
		  'apisecret' : credentials.apisecret, 
		});
			
        node.on('input', function(msg) {
			bittrexClient.getticker( { market : this.market }, function( data, err ) {
				if (err) {
					setErrorState(err);
				}
				node.send({payload: data.result, market: this.market});
			});			
        });
		
		function setErrorState(err) {
			node.status({fill:"red",shape:"ring",text:err})
        }

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("ticker",BittrexTickerNode);
	
	function BittrexBalanceNode(n) {
        RED.nodes.createNode(this,n);
		this.token = RED.nodes.getNode(n.token);
		this.currency = n.currency;
        var credentials = RED.nodes.getCredentials(n.token);
        var node = this;		
		
		bittrexClient.options({
		  'apikey' : credentials.apikey,
		  'apisecret' : credentials.apisecret, 
		});
			
        node.on('input', function(msg) {
			if (this.currency){
				bittrexClient.getbalance({ currency : this.currency }, function( data, err ) {
				  if (err) {
					setErrorState(err);
				  }
				  node.send({payload: data.result.Balance});
				  
				});	
			} else {
				bittrexClient.getbalances( function( data, err ) {
				  if (err) {
					return console.error(err);
				  }
				  
				  var result = {};
				  for (i in data.result) {
					result[data.result[i].Currency] = data.result[i].Balance
				  }
				  node.send({payload: result});
				});
			}			
        });
		
		function setErrorState(err) {
			node.status({fill:"red",shape:"ring",text:err})
        }

		node.on("close", function(done) {
			done();
        });		
	}
    RED.nodes.registerType("balance",BittrexBalanceNode);

	function BittrexTokenNode(n) {
        RED.nodes.createNode(this,n);
        this.name = n.name;
    }
    RED.nodes.registerType("bittrex-token",BittrexTokenNode,{
        credentials: {
            apikey: {type: "password"},
			apisecret: {type: "password"},
        }
    });
}
